// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetSupportLib = {
	$DOTNET: {
		conv_string: function (mono_obj) {
			return MONO.string_decoder.copy (mono_obj);
		}
	},
	mono_wasm_invoke_js_blazor: function(exceptionMessage, callInfo, arg0, arg1, arg2)	{
		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			var blazorExports = globalThis.Blazor;
			if (!blazorExports) {
				throw new Error('The blazor.webassembly.js library is not loaded.');
			}

			return blazorExports._internal.invokeJSFromDotNet(callInfo, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_marshalled: function(exceptionMessage, asyncHandleLongPtr, functionName, argsJson, treatResultAsVoid) {

		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			// Passing a .NET long into JS via Emscripten is tricky. The method here is to pass
			// as pointer to the long, then combine two reads from the HEAPU32 array.
			// Even though JS numbers can't represent the full range of a .NET long, it's OK
			// because we'll never exceed Number.MAX_SAFE_INTEGER (2^53 - 1) in this case.
			//var u32Index = $1 >> 2;
			var u32Index = asyncHandleLongPtr >> 2;
			var asyncHandleJsNumber = Module.HEAPU32[u32Index + 1]*4294967296 + Module.HEAPU32[u32Index];

			// var funcNameJsString = UTF8ToString (functionName);
			// var argsJsonJsString = argsJson && UTF8ToString (argsJson);
			var funcNameJsString = DOTNET.conv_string(functionName);
			var argsJsonJsString = argsJson && DOTNET.conv_string (argsJson);

			var dotNetExports = globaThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}

			if (asyncHandleJsNumber) {
				dotNetExports.jsCallDispatcher.beginInvokeJSFromDotNet(asyncHandleJsNumber, funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return 0;
			} else {
				var resultJson = dotNetExports.jsCallDispatcher.invokeJSFromDotNet(funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return resultJson === null ? 0 : mono_string(resultJson);
			}
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_unmarshalled: function(exceptionMessage, funcName, arg0, arg1, arg2)	{
		try {
			// Get the function you're trying to invoke
			var funcNameJsString = DOTNET.conv_string(funcName);
			var dotNetExports = globalThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}
			var funcInstance = dotNetExports.jsCallDispatcher.findJSFunction(funcNameJsString);

			return funcInstance.call(null, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var mono_string = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']); // TODO: Cache
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	}


};

autoAddDeps(DotNetSupportLib, '$DOTNET')
mergeInto(LibraryManager.library, DotNetSupportLib)


// SIG // Begin signature block
// SIG // MIIogwYJKoZIhvcNAQcCoIIodDCCKHACAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // DQxM5aUosMIFmI353dLRcro0jWTAvinWkY5FLkoNZqCg
// SIG // gg3lMIIGYzCCBEugAwIBAgITMwAAAwTBAxl+xgXkBAAA
// SIG // AAADBDANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1NloX
// SIG // DTIzMDgwMzIwMjM1NlowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAOHdTRLALlo0YXrnjKD38BEe
// SIG // NtbwT65kNWykLVVi5fg+iYy/NvqwmzM8B7jsikuqyuL5
// SIG // e9ofVzCImQrBnr8/kNWqCCRzY7BmSXPj/G6l3V4sdCvW
// SIG // W0w4phNSRODYv2llNrTrBYQ3VM8Qan7XPCiggyPpdLgI
// SIG // tgqCtUmRnhcLt+t1CJPyjBdXZsW9PEGvXp5rxEk/QjPw
// SIG // pLl0ByDhx/Q4Jl+Gt89xQISHyhp88bFpIq1hBoYX7Mj3
// SIG // MWELhURlVg9C6S7zbP4iKnRlPBaFOsWY2ZdgBdmq6SMo
// SIG // tiJy/0VfgqcWgoNzXlrzMhsnPp2RSHctBK/mhGJqBh4a
// SIG // m5L0hipV/aMmtQadwWqk17tKKCyokRU07fAeE2VgLZn1
// SIG // kFtTVMeWI80T86Df51nJEBd6wNpVf8Yu0PwZ9U4x6tPO
// SIG // nDHmGLDxumKik6EF07Ll9JC9j+x9qEs6+hEQZtvO37N1
// SIG // 1OeJfLi01NEw96gZtndSZwwg3fC3Y9mT/u0l2sVWK4lH
// SIG // siYCswIDAQABo4IBczCCAW8wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFHYemqRq
// SIG // 6/zTsNJ+DmUnNpbvNxiWMEUGA1UdEQQ+MDykOjA4MR4w
// SIG // HAYDVQQLExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xFjAU
// SIG // BgNVBAUTDTQ2NDIyMys0NzIyMzYwHwYDVR0jBBgwFoAU
// SIG // SG5k5VAF04KqFzc3IrVtqMp1ApUwVAYDVR0fBE0wSzBJ
// SIG // oEegRYZDaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNybDBhBggrBgEFBQcBAQRVMFMwUQYIKwYBBQUH
// SIG // MAKGRWh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvY2VydHMvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEB
// SIG // DAUAA4ICAQBWHX7gj/4B8GaQkHtPZBeCGJ8H6khiyj9r
// SIG // WCActkLMWVXfi1vnmcGTv9qYQxzmKLeE+c/pKcxFHCmf
// SIG // z3gnR8tQtzHBRvDILStRtGJfc/UFRysvP+CJZKBqqyhP
// SIG // w9J+2nrCe3r+womL1MlJUGnzrHIciPvLg7NHPXLmrekN
// SIG // m1GXURpiiGbVrpv5XbTE5L/o/u2hA8UheFhD9v12oZoY
// SIG // DxZgBIk0E+eYhv0QbblykcpwqANQHZoVM5RAZDpLwLKg
// SIG // LJ8TYjKvBiPaLZS3mN8W6GyBW5BjR6WFLGFmzPi1hkxh
// SIG // urwSKShhEb4y+BxER5NYq4b2IEXH8Bbs7nRos3peHdOQ
// SIG // ZYt+cY5LAITnrgKCl1pfcm9f/a99ap9mF8gNqKXa35IM
// SIG // yRY43Ic29BLK+kHw/WAVlGvaWRoV7gY1ThcLX70Xo9W3
// SIG // Poa/pSKePmHG7qYr5mkb8A1QjEyCPiXHILGnjN5anpxP
// SIG // ieLUp2bUu35T6qT2jZf3eG3ULpJfqtgvJHLdpghmzuoq
// SIG // SpLRgCj5RGJIGMjZ68mSwJJ0/wtuhsYs/xJnbqkHhSp5
// SIG // jQkb1t1tm8BU29E35iOOhDWcv2rXynVqgimthyytYk9R
// SIG // ZBmMHrMxr/vRjU2ZfK/3Ru0L0VDnmWO4Wnx9AoJv+R/c
// SIG // avpQWxjNn+C1qDD6gDUJNK/97Ie7Lte3ZjCCB3owggVi
// SIG // oAMCAQICCmEOkNIAAAAAAAMwDQYJKoZIhvcNAQELBQAw
// SIG // gYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1p
// SIG // Y3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
// SIG // eSAyMDExMB4XDTExMDcwODIwNTkwOVoXDTI2MDcwODIx
// SIG // MDkwOVowfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UE
// SIG // AxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAx
// SIG // MTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
// SIG // AKvw+nIQHC6t2G6qghBNNLrytlghn0IbKmvpWlCquAY4
// SIG // GgRJun/DDB7dN2vGEtgL8DjCmQawyDnVARQxQtOJDXlk
// SIG // h36UYCRsr55JnOloXtLfm1OyCizDr9mpK656Ca/XllnK
// SIG // YBoF6WZ26DJSJhIv56sIUM+zRLdd2MQuA3WraPPLbfM6
// SIG // XKEW9Ea64DhkrG5kNXimoGMPLdNAk/jj3gcN1Vx5pUkp
// SIG // 5w2+oBN3vpQ97/vjK1oQH01WKKJ6cuASOrdJXtjt7UOR
// SIG // g9l7snuGG9k+sYxd6IlPhBryoS9Z5JA7La4zWMW3Pv4y
// SIG // 07MDPbGyr5I4ftKdgCz1TlaRITUlwzluZH9TupwPrRkj
// SIG // hMv0ugOGjfdf8NBSv4yUh7zAIXQlXxgotswnKDglmDlK
// SIG // Ns98sZKuHCOnqWbsYR9q4ShJnV+I4iVd0yFLPlLEtVc/
// SIG // JAPw0XpbL9Uj43BdD1FGd7P4AOG8rAKCX9vAFbO9G9RV
// SIG // S+c5oQ/pI0m8GLhEfEXkwcNyeuBy5yTfv0aZxe/CHFfb
// SIG // g43sTUkwp6uO3+xbn6/83bBm4sGXgXvt1u1L50kppxMo
// SIG // pqd9Z4DmimJ4X7IvhNdXnFy/dygo8e1twyiPLI9AN0/B
// SIG // 4YVEicQJTMXUpUMvdJX3bvh4IFgsE11glZo+TzOE2rCI
// SIG // F96eTvSWsLxGoGyY0uDWiIwLAgMBAAGjggHtMIIB6TAQ
// SIG // BgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUSG5k5VAF
// SIG // 04KqFzc3IrVtqMp1ApUwGQYJKwYBBAGCNxQCBAweCgBT
// SIG // AHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQF
// SIG // MAMBAf8wHwYDVR0jBBgwFoAUci06AjGQQ7kUBU7h6qfH
// SIG // MdEjiTQwWgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDovL2Ny
// SIG // bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
// SIG // TWljUm9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNybDBe
// SIG // BggrBgEFBQcBAQRSMFAwTgYIKwYBBQUHMAKGQmh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWlj
// SIG // Um9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNydDCBnwYD
// SIG // VR0gBIGXMIGUMIGRBgkrBgEEAYI3LgMwgYMwPwYIKwYB
// SIG // BQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
// SIG // a2lvcHMvZG9jcy9wcmltYXJ5Y3BzLmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBwAG8AbABpAGMA
// SIG // eQBfAHMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAZ/KGpZjgVHkaLtPYdGcimwuWEeFj
// SIG // kplCln3SeQyQwWVfLiw++MNy0W2D/r4/6ArKO79HqaPz
// SIG // adtjvyI1pZddZYSQfYtGUFXYDJJ80hpLHPM8QotS0LD9
// SIG // a+M+By4pm+Y9G6XUtR13lDni6WTJRD14eiPzE32mkHSD
// SIG // jfTLJgJGKsKKELukqQUMm+1o+mgulaAqPyprWEljHwlp
// SIG // blqYluSD9MCP80Yr3vw70L01724lruWvJ+3Q3fMOr5ko
// SIG // l5hNDj0L8giJ1h/DMhji8MUtzluetEk5CsYKwsatruWy
// SIG // 2dsViFFFWDgycScaf7H0J/jeLDogaZiyWYlobm+nt3TD
// SIG // QAUGpgEqKD6CPxNNZgvAs0314Y9/HG8VfUWnduVAKmWj
// SIG // w11SYobDHWM2l4bf2vP48hahmifhzaWX0O5dY0HjWwec
// SIG // hz4GdwbRBrF1HxS+YWG18NzGGwS+30HHDiju3mUv7Jf2
// SIG // oVyW2ADWoUa9WfOXpQlLSBCZgB/QACnFsZulP0V3HjXG
// SIG // 0qKin3p6IvpIlR+r+0cjgPWe+L9rt0uX4ut1eBrs6jeZ
// SIG // eRhL/9azI2h15q/6/IvrC4DqaTuv/DDtBEyO3991bWOR
// SIG // PdGdVk5Pv4BXIqF4ETIheu9BCrE/+6jMpF3BoYibV3FW
// SIG // TkhFwELJm3ZbCoBIa/15n8G9bW1qyVJzEw16UM0xghn2
// SIG // MIIZ8gIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDExAhMzAAADBMEDGX7GBeQEAAAAAAMEMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCD3omjKU+2ltBtHmjuF
// SIG // e7vjmLFCFgQ9lehLg9Wo3349uDBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBgCT0R2IkihB3BAxTxsy6v5/As93NvlBouEXZ
// SIG // oX+WlYxDOYBxYvgcNiFLwheXvGnug05nxeuKKR15RwLW
// SIG // qzUyKaVW0JEuaPtIWowtJbKa+Ht2wSbdGKa+z8OVTesJ
// SIG // 5Jb83n9teI+wObuV/6xJXXhw/sm5qaXoDhjIVzTZJdWl
// SIG // vxgzAyc0X7supv2EgIcvC6i1PZO/+tAgNMxQu0YPZQFL
// SIG // 4jduvYHBlVm0JN+tZTgbi4U4EZSCPZpHj1J70JNosioq
// SIG // +0K50N8D6PgqtgDhQTU6BzenbLo3z0F+p9Y1TQv4WE0X
// SIG // zeSTSqphF2BdPUbInoMCXMEgLjurjcQvgFrSG+U7nBZQ
// SIG // ZJZ+GtPHfPoXXv1w0YBOaN6WIo8F10ZEsjFRUDwz1Lbk
// SIG // f47J2qciZdg6W/vfZ6pzCh2eSlx33S8n31pr/q+11E8n
// SIG // LaciacneskhqRsak8qwMJIYmckeeAVTZmsUIr8hQ9Uza
// SIG // 1X4Kp9QJ+xPVk61qoPzjDrP8CVdcrozxATBp6qGCFwAw
// SIG // ghb8BgorBgEEAYI3AwMBMYIW7DCCFugGCSqGSIb3DQEH
// SIG // AqCCFtkwghbVAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFR
// SIG // BgsqhkiG9w0BCRABBKCCAUAEggE8MIIBOAIBAQYKKwYB
// SIG // BAGEWQoDATAxMA0GCWCGSAFlAwQCAQUABCB3VN79WCOr
// SIG // E7lGOD8dDeUkJG2rjUcrvH+/DLPv+hBw9wIGZIt11hWW
// SIG // GBMyMDIzMDYyMzIzMjA0Mi4xNjhaMASAAgH0oIHQpIHN
// SIG // MIHKMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
// SIG // Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
// SIG // TWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxN
// SIG // aWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMSYwJAYD
// SIG // VQQLEx1UaGFsZXMgVFNTIEVTTjo4QTgyLUUzNEYtOURE
// SIG // QTElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAg
// SIG // U2VydmljZaCCEVcwggcMMIIE9KADAgECAhMzAAABwvp9
// SIG // hw5UU0ckAAEAAAHCMA0GCSqGSIb3DQEBCwUAMHwxCzAJ
// SIG // BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
// SIG // DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
// SIG // ZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29m
// SIG // dCBUaW1lLVN0YW1wIFBDQSAyMDEwMB4XDTIyMTEwNDE5
// SIG // MDEyOFoXDTI0MDIwMjE5MDEyOFowgcoxCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVy
// SIG // aWNhIE9wZXJhdGlvbnMxJjAkBgNVBAsTHVRoYWxlcyBU
// SIG // U1MgRVNOOjhBODItRTM0Ri05RERBMSUwIwYDVQQDExxN
// SIG // aWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNlMIICIjAN
// SIG // BgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAtfEJvPKO
// SIG // SFn3petp9wco29/UoJmDDyHpmmpRruRVWBF37By0nvrs
// SIG // zScOV/K+LvHWWWC4S9cme4P63EmNhxTN/k2CgPnIt/sD
// SIG // epyACSkya4ukqc1sT2I+0Uod0xjy9K2+jLH8UNb9vM3y
// SIG // H/vCYnaJSUqgtqZUly82pgYSB6tDeZIYcQoOhTI+M1Hh
// SIG // Rxmxt8RaAKZnDnXgLdkhnIYDJrRkQBpIgahtExtTuOkm
// SIG // Vp2y8YCoFPaUhUD2JT6hPiDD7qD7A77PLpFzD2QFmNez
// SIG // T8aHHhKsVBuJMLPXZO1k14j0/k68DZGts1YBtGegXNky
// SIG // vkXSgCCxt3Q8WF8laBXbDnhHaDLBhCOBaZQ8jqcFUx8Z
// SIG // JSXQ8sbvEnmWFZmgM93B9P/JTFTF6qBVFMDd/V0PBbRQ
// SIG // C2TctZH4bfv+jyWvZOeFz5yltPLRxUqBjv4KHIaJgBhU
// SIG // 2ntMw4H0hpm4B7s6LLxkTsjLsajjCJI8PiKi/mPKYERd
// SIG // mRyvFL8/YA/PdqkIwWWg2Tj5tyutGFtfVR+6GbcCVhij
// SIG // jy7l7otxa/wYVSX66Lo0alaThjc+uojVwH4psL+A1qvb
// SIG // WDB9swoKla20eZubw7fzCpFe6qs++G01sst1SaA0GGmz
// SIG // uQCd04Ue1eH3DFRDZPsN+aWvA455Qmd9ZJLGXuqnBo4B
// SIG // XwVxdWZNj6+b4P8CAwEAAaOCATYwggEyMB0GA1UdDgQW
// SIG // BBRGsYh76V41aUCRXE9WvD++sIfGajAfBgNVHSMEGDAW
// SIG // gBSfpxVdAF5iXYP05dJlpxtTNRnpcjBfBgNVHR8EWDBW
// SIG // MFSgUqBQhk5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20v
// SIG // cGtpb3BzL2NybC9NaWNyb3NvZnQlMjBUaW1lLVN0YW1w
// SIG // JTIwUENBJTIwMjAxMCgxKS5jcmwwbAYIKwYBBQUHAQEE
// SIG // YDBeMFwGCCsGAQUFBzAChlBodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL2NlcnRzL01pY3Jvc29mdCUy
// SIG // MFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNydDAM
// SIG // BgNVHRMBAf8EAjAAMBMGA1UdJQQMMAoGCCsGAQUFBwMI
// SIG // MA0GCSqGSIb3DQEBCwUAA4ICAQARdu3dCkcLLPfaJ3rR
// SIG // 1M7D9jWHvneffkmXvFIJtqxHGWM1oqAh+bqxpI7HZz2M
// SIG // eNhh1Co+E9AabOgj94Sp1seXxdWISJ9lRGaAAWzA873a
// SIG // TB3/SjwuGqbqQuAvUzBFCO40UJ9anpavkpq/0nDqLb7X
// SIG // I5H+nsmjFyu8yqX1PMmnb4s1fbc/F30ijaASzqJ+p5rr
// SIG // gYWwDoMihM5bF0Y0riXihwE7eTShak/EwcxRmG3h+OT+
// SIG // Ox8KOLuLqwFFl1siTeQCp+YSt4J1tWXapqGJDlCbYr3R
// SIG // z8+ryTS8CoZAU0vSHCOQcq12Th81p7QlHZv9cTRDhZg2
// SIG // TVyg8Gx3X6mkpNOXb56QUohI3Sn39WQJwjDn74J0aVYM
// SIG // ai8mY6/WOurKMKEuSNhCiei0TK68vOY7sH0XEBWnRSbV
// SIG // efeStDo94UIUVTwd2HmBEfY8kfryp3RlA9A4FvfUvDHM
// SIG // aF9BtvU/pK6d1CdKG29V0WN3uVzfYETJoRpjLYFGq0Mv
// SIG // K6QVMmuNxk3bCRfj1acSWee14UGjglxWwvyOfNJe3pxc
// SIG // NFOd8Hhyp9d4AlQGVLNotaFvopgPLeJwUT3dl5VaAAhM
// SIG // wvIFmqwsffQy93morrprcnv74r5g3ejC39NYpFEoy+qm
// SIG // zLW1jFa1aXE2Xb/KZw2yawqldSp0Hu4VEkjGxFNc+Azt
// SIG // IUWwmTCCB3EwggVZoAMCAQICEzMAAAAVxedrngKbSZkA
// SIG // AAAAABUwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290
// SIG // IENlcnRpZmljYXRlIEF1dGhvcml0eSAyMDEwMB4XDTIx
// SIG // MDkzMDE4MjIyNVoXDTMwMDkzMDE4MzIyNVowfDELMAkG
// SIG // A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
// SIG // BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
// SIG // dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0
// SIG // IFRpbWUtU3RhbXAgUENBIDIwMTAwggIiMA0GCSqGSIb3
// SIG // DQEBAQUAA4ICDwAwggIKAoICAQDk4aZM57RyIQt5osvX
// SIG // JHm9DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25Phdg
// SIG // M/9cT8dm95VTcVrifkpa/rg2Z4VGIwy1jRPPdzLAEBjo
// SIG // YH1qUoNEt6aORmsHFPPFdvWGUNzBRMhxXFExN6AKOG6N
// SIG // 7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6Gnsz
// SIG // rYBbfowQHJ1S/rboYiXcag/PXfT+jlPP1uyFVk3v3byN
// SIG // pOORj7I5LFGc6XBpDco2LXCOMcg1KL3jtIckw+DJj361
// SIG // VI/c+gVVmG1oO5pGve2krnopN6zL64NF50ZuyjLVwIYw
// SIG // XE8s4mKyzbnijYjklqwBSru+cakXW2dg3viSkR4dPf0g
// SIG // z3N9QZpGdc3EXzTdEonW/aUgfX782Z5F37ZyL9t9X4C6
// SIG // 26p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0lBw0gg/wEPK3
// SIG // Rxjtp+iZfD9M269ewvPV2HM9Q07BMzlMjgK8QmguEOqE
// SIG // UUbi0b1qGFphAXPKZ6Je1yh2AuIzGHLXpyDwwvoSCtdj
// SIG // bwzJNmSLW6CmgyFdXzB0kZSU2LlQ+QuJYfM2BjUYhEfb
// SIG // 3BvR/bLUHMVr9lxSUV0S2yW6r1AFemzFER1y7435UsSF
// SIG // F5PAPBXbGjfHCBUYP3irRbb1Hode2o+eFnJpxq57t7c+
// SIG // auIurQIDAQABo4IB3TCCAdkwEgYJKwYBBAGCNxUBBAUC
// SIG // AwEAATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6CkTxG
// SIG // NSnPEP8vBO4wHQYDVR0OBBYEFJ+nFV0AXmJdg/Tl0mWn
// SIG // G1M1GelyMFwGA1UdIARVMFMwUQYMKwYBBAGCN0yDfQEB
// SIG // MEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWljcm9z
// SIG // b2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBvc2l0b3J5Lmh0
// SIG // bTATBgNVHSUEDDAKBggrBgEFBQcDCDAZBgkrBgEEAYI3
// SIG // FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYD
// SIG // VR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbLj+ii
// SIG // XGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBNMEugSaBHhkVo
// SIG // dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9w
// SIG // cm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5j
// SIG // cmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUFBzAChj5o
// SIG // dHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRz
// SIG // L01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDANBgkq
// SIG // hkiG9w0BAQsFAAOCAgEAnVV9/Cqt4SwfZwExJFvhnnJL
// SIG // /Klv6lwUtj5OR2R4sQaTlz0xM7U518JxNj/aZGx80HU5
// SIG // bbsPMeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYunKmC
// SIG // VgADsAW+iehp4LoJ7nvfam++Kctu2D9IdQHZGN5tggz1
// SIG // bSNU5HhTdSRXud2f8449xvNo32X2pFaq95W2KFUn0CS9
// SIG // QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wMnosZ
// SIG // iefwC2qBwoEZQhlSdYo2wh3DYXMuLGt7bj8sCXgU6ZGy
// SIG // qVvfSaN0DLzskYDSPeZKPmY7T7uG+jIa2Zb0j/aRAfbO
// SIG // xnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2dY3RILLFO
// SIG // Ry3BFARxv2T5JL5zbcqOCb2zAVdJVGTZc9d/HltEAY5a
// SIG // GZFrDZ+kKNxnGSgkujhLmm77IVRrakURR6nxt67I6Ile
// SIG // T53S0Ex2tVdUCbFpAUR+fKFhbHP+CrvsQWY9af3LwUFJ
// SIG // fn6Tvsv4O+S3Fb+0zj6lMVGEvL8CwYKiexcdFYmNcP7n
// SIG // tdAoGokLjzbaukz5m/8K6TT4JDVnK+ANuOaMmdbhIurw
// SIG // J0I9JZTmdHRbatGePu1+oDEzfbzL6Xu/OHBE0ZDxyKs6
// SIG // ijoIYn/ZcGNTTY3ugm2lBRDBcQZqELQdVTNYs6FwZvKh
// SIG // ggLOMIICNwIBATCB+KGB0KSBzTCByjELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJp
// SIG // Y2EgT3BlcmF0aW9uczEmMCQGA1UECxMdVGhhbGVzIFRT
// SIG // UyBFU046OEE4Mi1FMzRGLTlEREExJTAjBgNVBAMTHE1p
// SIG // Y3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2WiIwoBATAH
// SIG // BgUrDgMCGgMVAMp1N1VLhPMvWXEoZfmF4apZlnRUoIGD
// SIG // MIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UE
// SIG // AxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
// SIG // DQYJKoZIhvcNAQEFBQACBQDoQH+7MCIYDzIwMjMwNjI0
// SIG // MDQzMTU1WhgPMjAyMzA2MjUwNDMxNTVaMHcwPQYKKwYB
// SIG // BAGEWQoEATEvMC0wCgIFAOhAf7sCAQAwCgIBAAICK0oC
// SIG // Af8wBwIBAAICFJYwCgIFAOhB0TsCAQAwNgYKKwYBBAGE
// SIG // WQoEAjEoMCYwDAYKKwYBBAGEWQoDAqAKMAgCAQACAweh
// SIG // IKEKMAgCAQACAwGGoDANBgkqhkiG9w0BAQUFAAOBgQA2
// SIG // HO94+EE31JbQacBxOWFxjBdNM7ODxdqWn/6cFzvaX5e4
// SIG // O4DNnNgDm9GWDC0nWrJo2g767nF/yUg9u3nW2v3y1pLw
// SIG // IBX5n/FAbvRSL8VqPRChV25Yf5fid5aDhkQwxgQqezaa
// SIG // ea0Iwp1iVd0qHHenEFn/Tq4l0Tjb3n9clcpyPzGCBA0w
// SIG // ggQJAgEBMIGTMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
// SIG // EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
// SIG // HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAk
// SIG // BgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAy
// SIG // MDEwAhMzAAABwvp9hw5UU0ckAAEAAAHCMA0GCWCGSAFl
// SIG // AwQCAQUAoIIBSjAaBgkqhkiG9w0BCQMxDQYLKoZIhvcN
// SIG // AQkQAQQwLwYJKoZIhvcNAQkEMSIEIKIOoER5mXFeqLBn
// SIG // wF4+pwOP1CMcKWvj6QPzwYqacV/EMIH6BgsqhkiG9w0B
// SIG // CRACLzGB6jCB5zCB5DCBvQQgypNgW8fpsMV57r0F5beU
// SIG // uiEVOVe4BdmaO+e28mGDUBYwgZgwgYCkfjB8MQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQg
// SIG // VGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAcL6fYcOVFNH
// SIG // JAABAAABwjAiBCDwpdiHheFk1NmqY14UfwW+wTG660QE
// SIG // X56tk1UIK8/7bzANBgkqhkiG9w0BAQsFAASCAgA7jrM6
// SIG // nh62pe//Ae+1WF+2ds10lr7d5dCV/8cVK0CNAYRUD8pJ
// SIG // /z0BtLVCwkM9Kmk5dF+xMsDlO8baftQy4Y5gb2enulpf
// SIG // AlSUyHwJDLDBd2xvH0Ifox3E024ft4+JwyiBKa6Oq1dQ
// SIG // DlNReJxVF+g9x1VEZvrSwm2VfK6uAKjes+DJert2BU04
// SIG // TRgTlXvbPD8g9gWUcns+pKdCMOhVljK9nz7+u18JmLrQ
// SIG // dZLIdF+7wHbaOUbIC1CIYAEyMyRjA8lz0doapZK9BW/k
// SIG // /7zkXk5u158nEIo0gIVpshnNWBmMm+9Aq58dUJDrLVtG
// SIG // WmSmDPxLNtRTOGMjvhR50LdmGJknkMEi1lKbIIs9u4lP
// SIG // KlMe8DmwxnAgxEkw5uEeaQeO9ea/A1hMOO4VhyJWPD7k
// SIG // si6FHdF+4Y50SN4ODa8IMErU0QgjejFwjCqmcOySwOwU
// SIG // ZTYzB6AJnog/e/knpfIgJb3lGWichlldifBIHH2DxX9J
// SIG // jodveSqCi0bcy7/QMy2ujphNysfQuyVjjZKDp2ggA2iV
// SIG // KPRLueDw1VT4nXIGt31GUh+4MLUZVnLXFbNqw4tMdaKM
// SIG // 4/CfBECbIjpGTmZLJQdEh39r8gajNjbUVhATIht9VNio
// SIG // 5pi9rOfVydRacHsQeOWfQ6O3KNCKHc1YtopfxLxGTAgr
// SIG // /25bhYHSHQMVq5xIDA==
// SIG // End signature block
